=========
 CHANGES
=========

4.0.0 (2017-05-17)
==================

- Add support for Python 3.4, 3.5, 3.6 and PyPy.

- Remove dependency on ``zope.app.testing``.

- Use the standard library ``doctest`` module.

3.5.1 (2009-07-21)
==================

- Require the new ``roman`` package, since docutils does not install it
  correctly.

3.5.0 (2009-01-17)
==================

- Adapted to docutils 0.5 for ReST rendering: get rid of the
  ZopeTranslator class, because docutils changed the way it
  uses translator so previous implementation doesn't work anymore.
  Instead, use publish_parts and join needed parts in the ``render``
  method of the renderer itself.

- Removed deprecated meta.zcml stuff and zpkg stuff.

- Replaced __used_for__ with zope.component.adapts calls.

3.4.0 (2007-10-27)
==================

- Initial release independent of the main Zope tree.
